SQL Statements and Expressions API — SQLAlchemy 1.2 Documentation

Release: 1.2.0 | Release Date: December 27, 2017

# SQLAlchemy 1.2 Documentation

# SQL Statements and Expressions API

This section presents the API reference for the SQL Expression Language. For a full introduction to its usage, see SQL Expression Language Tutorial.

- Column Elements and Expressions
- Selectables, Tables, FROM objects
- Insert, Updates, Deletes
- SQL and Generic Functions
- Custom SQL Constructs and Compilation Extension
- Expression Serializer Extension